/**********************************************************************/
/*                                                                    */
/* Licensed Materials - Property of UNICOM Systems, Inc.              */
/* Licensed Materials - Property of IBM                               */
/* 5698-T03                                                           */
/*                                                                    */
/*  Copyright 2019-2020 UNICOM Systems, Inc. All rights reserved.    */
/*                                                                    */
/*  Copyright IBM Corporation 1999, 2013                             */
/*  Copyright Candle Corporation 1999, 2004.  All rights reserved.   */
/*                                                                    */
/* US Government Users Restricted Rights - Use, duplication, or       */
/* disclosure restricted by GSA ADP schedule contract with            */
/* IBM Corp. and/or with UNICOM Systems, Inc.                         */
/*                                                                    */
/**********************************************************************/
/* ------------------------------------------------------------------ */
/*  Name:    kn3.sql                                                  */
/*  Purpose: kn3.sql product provided situation inserts               */
/* ------------------------------------------------------------------ */
/*  Date        | User  | Description                                 */
/* ------------------------------------------------------------------ */
/*  2002/02/20  | CMIKS | Created                                     */
/*  2002/02/25  | CMIKS | Added template statuses for situations not  */
/*              |       | associated with leafnode workspaces (e.g.,  */
/*              |       | summary workspaces)                         */
/*  2002/03/20  | CMIKS | Added distributions                         */
/*  2002/03/20  | CMIKS | Expert Advice via $PARM                     */
/*  2002/05/01  | MGOUV | $PARM expert advise for                     */
/*                        N3T_Device_Status_Active                    */
/*  2002/05/14  | RSMIT | Changed attribute names to 1st char caps    */
/*  2003/04/14  | TEHRL | Added OSA situations                        */
/*  2003/12/09  | MGOUV | N3 V100 OSA Situations                      */
/*  2004/10/18  | MGOUV | Change in situation affinities              */
/*  2004/11/16  | AYOUN | Additional situations for NMI data          */
/*  2005/02/04  | AYOUN | Changes for TCN table split up              */
/*  2005/03/11  | AYOUN | Additional situations for Stack Layer       */
/*  2005/06/13  | AYOUN | Change Pct_TCP_OO_Segs to use percent       */
/*  2005/07/11  | MGOUV | Add sits for VTAM Address Space workspace   */
/*  2005/12/03  | MGOUV | Add sits for VTAM Buffer Pool workspaces    */
/*  2006/02/01  | OCB   | Exploit z/OS NMI FTP enhancements           */
/*  2006/03/13  | OCB   | D24711 - Adjust situation N3T_FTPT_NetError */
/*              |       | so it does not fire when client aborts      */
/*              |       | transfer (last reply to client = 426).      */
/*              |       | Situation N3T_FTPS_NetError was also        */
/*              |       | adjusted so that it does not fire for a     */
/*              |       | session end code of 10.                     */
/*  FLG=REASON  ,RELEASE,DATE  ,USER : DESCRIPTION                    */
/*  --- -------- ------- ------ -----  ------------------------------ */
/*  @01=DCR41   ,HKN3410,032906,MGOUV: Version V410 situations        */
/*  @02=DCR41   ,HKN3410,050206,MGOUV: More Version changes           */
/*  @03=D32858  ,HKN3410,072506,MGOUV: Lodge error in Device sits     */
/*  @04=D53101  ,HKN3410,082907,OBRAB: Use CHANGE function in IPSec   */
/*                                     sits                           */
/*  @05=OSAIII  ,HKN3410,011608,MGOUV: OSA Express3 support           */
/*  @06=68881   ,HKN3410,032608,DBUTL: Add SITINFO value SEV=...      */
/*  @07=621INTG ,HKN3420,010809,MGOUV: DCR 97 and Eliminate Hub TEMS  */
/*                                     recycles (seed)                */
/*  @08=D113781 ,HKN3421,090309,MGOUV: Sit seeding problem on xLinux  */
/*  @09=D115310 ,HKN3421,100209,OBRAB: Sample sits to trigger NetView */
/*                                     automation                     */
/*  @0A=RTC6369 ,HKN3423,032310,MPATT: GUI Enhancements               */
/*  @0B=RTC7788B,HKN3423,042010,MPATT: TCP GUI enhancements           */
/*  @0C=RTC8542 ,HKN3423,050410,MPATT: IFR/IFW GUI Enhancements       */
/*  @0D=RTC8542 ,HKN3423,051810,MPATT: IFR/IFW GUI Enhancements       */
/*  @0E=RTC9497 ,HKN3423,060910,MPATT: IFS GUI enhancements           */
/*  @0F=RTC9497B,HKN3423,061710,MPATT: Rename situation               */
/*  @0G=F133307 ,HKN3423,062210,MPATT: Globalization                  */
/*  @0H=Fxxxxxx ,HKN3511,013013,MGOUV: Don't distribute situations    */
/*  @10=OA57939 ,HKN3550,111219,DAB  : FP3, PTF UJ00469 - VTAM Apps   */
/*  @11=OA57939 ,HKN3550,111219,MCG  : FP4, UJ00469 - zERT Updates    */
/*  @12=OA59322 ,HKN3550,071420,DAB  : FP5, UJ03159 - OSA7S & OSA5S   */
/* ------------------------------------------------------------------ */
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Appl_Backlog_Conns_Rejec
ted";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE TCPIP_Applications.Backlog_Connections_Rejected *GE 3",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Appl_Backlog_Conns_Rejected",
   "Kn3:KN32000",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Appl_Byte_Rate";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF  *VALUE TCPIP_Applications.Byte_Rate *GE 1000000",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Appl_Byte_Rate",
   "Kn3:KN32001",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Appl_Connections_in_Back
log";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE TCPIP_Applications.Connections_in_Backlog *GE 10",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Appl_Connections_in_Backlog",
   "Kn3:KN32002",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Appl_Datagram_Rate";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF  *VALUE TCPIP_Applications.Datagram_Rate *GE 500",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Appl_Datagram_Rate",
   "Kn3:KN32003",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Appl_FTPD1_Rate";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF  *VALUE TCPIP_Applications.Application_Name *EQ FTPD1 *AND  *VAL
UE TCPIP_Applications.Byte_Rate *GE 100000",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Appl_FTPD1_Rate",
   "Kn3:KN32004",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Appl_Not_Accepting_Conn"
;
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF  *VALUE TCPIP_Applications.Connections_in_Backlog *GT 0 *AND  *V
ALUE TCPIP_Applications.Idle_Time_Since_Last_Accept *GE 0.02",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Appl_Not_Accepting_Conn",
   "Kn3:KN32005",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Appl_Pct_Datagrams_Discd
";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE TCPIP_Applications.Pct_Datagrams_Discarded *GE 3",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Appl_Pct_Datagrams_Discd",
   "Kn3:KN32006",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Appl_Pct_OO_Segments";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE TCPIP_Applications.Pct_Out_of_Order_Segments *GE 15",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Appl_Pct_OO_Segments",
   "Kn3:KN32007",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Appl_Pct_Segs_Rexmit";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE TCPIP_Applications.Retransmits_Percentage *GE 3",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Appl_Pct_Segs_Rexmit",
   "Kn3:KN32008",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Appl_Reject_Conn";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE TCP_Listener.Conn_High_Water_Mark_Percentage *GE 80 *AND
 *VALUE TCP_Listener.Conn_High_Water_Mark_Percentage *LE 90 *AND  *VALUE
 TCP_Listener.Backlog_Connections_Rejected *GT 0",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Appl_Reject_Conn",
   "Kn3:KN32009",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Appl_Reject_Conn_Resourc
e";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE TCP_Listener.Conn_High_Water_Mark_Percentage *LE 80 *AND
 *VALUE TCP_Listener.Backlog_Connections_Rejected *GT 0",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Appl_Reject_Conn_Resource",
   "Kn3:KN32010",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Appl_Reject_Conn_WorkSpi
ke";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE TCP_Listener.Conn_High_Water_Mark_Percentage *GE 90 *AND
 *VALUE TCP_Listener.Backlog_Connections_Rejected *GT 0",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Appl_Reject_Conn_WorkSpike",
   "Kn3:KN32011",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Appl_Retransmission_Coun
t";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF  *VALUE TCPIP_Applications.Retransmits_Last_Sample *GE 10",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Appl_Retransmission_Count",
   "Kn3:KN32012",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_CPU_Pct_Critical";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF  *VALUE TCPIP_Address_Space.CPU_Percentage *GE 10",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_CPU_Pct_Critical",
   "Kn3:KN32013",
   "NNN",
   "SEV=Critical",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_CPU_Pct_Warning";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF  *VALUE TCPIP_Address_Space.CPU_Percentage *GE 5 *AND  *VALUE TC
PIP_Address_Space.CPU_Percentage *LT 10",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_CPU_Pct_Warning",
   "Kn3:KN32014",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_CSA_Pct_Below_16MB";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF  *VALUE TCPIP_Address_Space.CSA_Percent_Below_16MB *GE 5",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_CSA_Pct_Below_16MB",
   "Kn3:KN32015",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Conn_Backlog_Conns_Rejec
ted";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE TCP_Listener.Backlog_Connections_Rejected *GE 3",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Conn_Backlog_Conns_Rejected",
   "Kn3:KN32016",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Conn_Byte_Rate";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF  *VALUE TCPIP_Connections.Byte_Rate *GE 750000",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Conn_Byte_Rate",
   "Kn3:KN32017",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Conn_Connections_in_Back
log";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE TCP_Listener.Connections_in_Backlog *GE 10",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Conn_Connections_in_Backlog",
   "Kn3:KN32018",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Conn_Current_Retransmits
";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF  *VALUE TCPIP_Connections.Retransmits_Last_Sample *GE 5",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Conn_Current_Retransmits",
   "Kn3:KN32019",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Conn_Datagram_Rate";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF  *VALUE TCPIP_Connections.Datagram_Rate *GE 1000",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Conn_Datagram_Rate",
   "Kn3:KN32020",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Conn_Pct_Datagrams_Discd
";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE UDP_Connections.Pct_Datagram_Discarded *GE 3",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Conn_Pct_Datagrams_Discd",
   "Kn3:KN32021",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Conn_Pct_OO_Segments";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE TCPIP_Details.Pct_Out_of_Order_Segments *GE 15",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Conn_Pct_OO_Segments",
   "Kn3:KN32022",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Conn_Pct_Segs_Rexmit";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE TCPIP_Connections.Retransmit_Percentage *GE 3",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Conn_Pct_Segs_Rexmit",
   "Kn3:KN32023",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Conn_Rnd_Trip_Time";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF  *VALUE TCPIP_Connections.Round_Trip_Time *GE 5",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Conn_Rnd_Trip_Time",
   "Kn3:KN32024",
   "NNN",
   "SEV=Critical",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Conn_Rnd_Trip_Variance";

INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE TCPIP_Connections.Round_Trip_Variance *GE 5",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Conn_Rnd_Trip_Variance",
   "Kn3:KN32025",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Connection_Count";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF  *VALUE TCPIP_Address_Space.Connection_Count *GE 5000",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Connection_Count",
   "Kn3:KN32026",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_DLC_Accelerated_Bytes";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000080000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130121080820000",
   "V4203",
   "SYSADMIN",
   "",
   "*IF *VALUE KN3_Interface_Write_Queue.IP_Address_Version *EQ IPv4 *AN
D *VALUE KN3_Interface_Write_Queue.QDIO_Accelerator *EQ Yes *AND *CHANGE
 KN3_Interface_Write_Queue.Accelerated_Bytes *EQ 0",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_DLC_Accelerated_Bytes",
   "Kn3:KN320101731252461458",
   "NNN",
   "COUNT=3;SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_DLC_Max_Staging_Queue_De
pth";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000080000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130121080820000",
   "V4203",
   "SYSADMIN",
   "",
   "*IF *CHANGE KN3_Interface_Write_Queue.Max_Staging_Queue_Depth *GT 0"
,
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_DLC_Max_Staging_Queue_Depth",
   "Kn3:KN320101731252461459",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_DLC_Read_Deferrals";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000080000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130121080820000",
   "V4203",
   "SYSADMIN",
   "",
   "*IF *VALUE KN3_Interface_Read_Queue.Delta_Read_Process_Defer *GT 0",

   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_DLC_Read_Deferrals",
   "Kn3:KN320101731252461460",
   "NNN",
   "SEV=Critical",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_DLC_Reads_Exhausted";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000080000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130121080820000",
   "V4203",
   "SYSADMIN",
   "",
   "*IF *VALUE KN3_Interface_Read_Queue.Delta_Reads_Exhausted *GT 0",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_DLC_Reads_Exhausted",
   "Kn3:KN320101731252461461",
   "NNN",
   "SEV=Critical",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Device_Status_Active";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF  *VALUE TCPIP_Devices.Device_Status *EQ up",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Device_Status_Active",
   "Kn3:KN32027",
   "NNY",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Device_Status_Inactive";

INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF  *VALUE TCPIP_Devices.Device_Status *EQ down",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Device_Status_Inactive",
   "Kn3:KN32028",
   "NNY",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_FTPS_InvalidSeq";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000008000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE FTP_Sessions.Session_End_Reason_Code *EQ 4 *AND *VALUE FT
P_Sessions.FTP_Type *EQ Server",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_FTPS_InvalidSeq",
   "Kn3:KN3200673101281022",
   "NNY",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_FTPS_NetError";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000008000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF ( ( *VALUE FTP_Sessions.FTP_Type *EQ Client *AND *VALUE FTP_Sess
ions.Session_End_Reason_Code *GE 8 *AND *VALUE FTP_Sessions.Session_End_
Reason_Code *LE 9 ) *OR ( *VALUE FTP_Sessions.FTP_Type *EQ Server *AND *
VALUE FTP_Sessions.Session_End_Reason_Code *EQ 2 ) )",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_FTPS_NetError",
   "Kn3:KN3200673101281023",
   "NNY",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_FTPS_ServerError";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000008000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE FTP_Sessions.FTP_Type *EQ Client *AND *VALUE FTP_Sessions
.Session_End_Reason_Code *EQ 2",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_FTPS_ServerError",
   "Kn3:KN3200673101281024",
   "NNY",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_FTPS_SysError";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000008000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE FTP_Sessions.Session_End_Reason_Code *EQ 1 *AND *VALUE FT
P_Sessions.FTP_Type *EQ Client",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_FTPS_SysError",
   "Kn3:KN3200673101281025",
   "NNY",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_FTPT_FileSysError";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000008000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF ( ( *VALUE TCPIP_FTP.Last_Reply *GT 450 *AND *VALUE TCPIP_FTP.La
st_Reply *LT 460 ) *OR ( *VALUE TCPIP_FTP.Last_Reply *GT 550 *AND *VALUE
 TCPIP_FTP.Last_Reply *LT 560 ) )",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_FTPT_FileSysError",
   "Kn3:KN3200673101281026",
   "NNY",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_FTPT_NetError";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000008000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE TCPIP_FTP.Last_Reply *EQ '425'",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_FTPT_NetError",
   "Kn3:KN3200673101281027",
   "NNY",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Fragmentation_Failure_Pc
t";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF  *VALUE TCPIP_Address_Space.Fragmentation_Failure_Percentage *GE
 5",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Fragmentation_Failure_Pct",
   "Kn3:KN32029",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Fragmentation_Pct";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF  *VALUE TCPIP_Address_Space.Fragmentation_Percentage *GE 5",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Fragmentation_Pct",
   "Kn3:KN32030",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_IF_Rcv_Util";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE Interfaces.Receive_Bandwidth_Utilization *GE 95",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_IF_Rcv_Util",
   "Kn3:KN32031",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_IF_Util";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE Interfaces.Bandwidth_Utilization *GE 95",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_IF_Util",
   "Kn3:KN32032",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_IF_Xmt_Util";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE Interfaces.Transmit_Bandwidth_Utilization *GE 95",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_IF_Xmt_Util",
   "Kn3:KN32033",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_IPSec_Dyn_Act_Fail";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("000000000000000000000000200000000G000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *CHANGE IPSec_Status.Tot_Failed_Dyn_Tunnel_Act *GT 0",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_IPSec_Dyn_Act_Fail",
   "Kn3:KN32007204955441508",
   "NNY",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_IPSec_Dyn_Act_Fail_IKE_T
nR";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("000000000000000000000000200000000G000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130125110056000",
   "V100",
   "SYSADMIN",
   "",
   "*IF *CHANGE IKE_Tunnels.Tot_Failed_Remote_Activations *GT 0",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_IPSec_Dyn_Act_Fail_IKE_TnR",
   "Kn3:KN3200724813601000",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_IPSec_Dyn_Act_Fail_IKE_T
nl";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("000000000000000000000000200000000G000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *CHANGE IKE_Tunnels.Tot_Failed_Local_Activations *GT 0",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_IPSec_Dyn_Act_Fail_IKE_Tnl",
   "Kn3:KN3200724813601001",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_IPSec_IKE_Act_Fail";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("000000000000000000000000200000000G000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *CHANGE IPSec_Status.Tot_Failed_IKE_Tunnel_Act *GT 0",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_IPSec_IKE_Act_Fail",
   "Kn3:KN32007204955441510",
   "NNY",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_IPSec_Key_Msgs_Auth_Fail
";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("000000000000000000000000200000000G000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *CHANGE IPSec_Status.IKE_Tot_Key_Message_Auth_Fail *GT 0",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_IPSec_Key_Msgs_Auth_Fail",
   "Kn3:KN32007204955441511",
   "NNY",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_IPSec_Key_Msgs_Invalid";

INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("000000000000000000000000200000000G000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *CHANGE IPSec_Status.IKE_Tot_Invalid_Key_Msgs *GT 0",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_IPSec_Key_Msgs_Invalid",
   "Kn3:KN32007204955441512",
   "NNY",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_IPSec_Key_Msgs_Replayed"
;
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("000000000000000000000000200000000G000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *CHANGE IPSec_Status.IKE_Tot_Replayed_Key_Msgs *GT 5",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_IPSec_Key_Msgs_Replayed",
   "Kn3:KN32007204955441513",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_IPSec_Key_Msgs_Rtrnsmttd
";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("000000000000000000000000200000000G000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *CHANGE IPSec_Status.IKE_Tot_Retransmitted_Key_Msgs *GT 5",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_IPSec_Key_Msgs_Rtrnsmttd",
   "Kn3:KN32007204955441514",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_IPSec_Pkts_Denied_DENY";

INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("000000000000000000000000200000000G000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE IPSec_Status.Pct_Packets_Denied_By_DENY *GT 5",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_IPSec_Pkts_Denied_DENY",
   "Kn3:KN32007204955441515",
   "NNY",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_IPSec_Pkts_Denied_Mismat
ch";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("000000000000000000000000200000000G000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE Current_IP_Filters.Packets_Denied_By_Mismatch *GT 0",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_IPSec_Pkts_Denied_Mismatch",
   "Kn3:KN32007204955441516",
   "NNY",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_IPSec_QUICKMODE_Invalid"
;
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("000000000000000000000000200000000G000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *CHANGE IPSec_Status.Tot_Invalid_QUICKMODE_Msgs *GT 0",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_IPSec_QUICKMODE_Invalid",
   "Kn3:KN32007204955441517",
   "NNY",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_IPSec_QUICKMODE_Replayed
";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("000000000000000000000000200000000G000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *CHANGE IPSec_Status.Tot_Replayed_QUICKMODE_Msgs *GT 5",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_IPSec_QUICKMODE_Replayed",
   "Kn3:KN32007204955441518",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_IPSec_QUICKMODE_Rtrnsmtt
d";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("000000000000000000000000200000000G000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *CHANGE IPSec_Status.Tot_Rtrnsmttd_QUICKMODE_Msgs *GT 5",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_IPSec_QUICKMODE_Rtrnsmttd",
   "Kn3:KN32007204955441519",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_IP_Input_Discard_Pct";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000080000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130121080820000",
   "V4203",
   "SYSADMIN",
   "",
   "*IF *VALUE KN3_IP_Counter_Statistics.Input_Discard_Percentage *GE 3"
,
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_IP_Input_Discard_Pct",
   "Kn3:KN320101731252461462",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_IP_Out_Disc";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE TCPIP_Stack_Layer.Output_Discards *GE 10",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_IP_Out_Disc",
   "Kn3:KN32034",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_IP_Output_Discard_Pct";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000080000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130121080820000",
   "V4203",
   "SYSADMIN",
   "",
   "*IF *VALUE KN3_IP_Counter_Statistics.Output_Discard_Percentage *GE 3
",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_IP_Output_Discard_Pct",
   "Kn3:KN320101731252461463",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Input_Discard_Pct";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF  *VALUE TCPIP_Address_Space.Input_Discard_Percentage *GE 5",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Input_Discard_Pct",
   "Kn3:KN32035",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Interface_Bandwidth_Util
";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000080000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130121080820000",
   "V4203",
   "SYSADMIN",
   "",
   "*IF *VALUE KN3_Interface_Statistics.Bandwidth_Utilization *GE 95",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Interface_Bandwidth_Util",
   "Kn3:KN320101731252461464",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Interface_Xmit_Rcv_Bytes
";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000080000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130121080820000",
   "V4203",
   "SYSADMIN",
   "",
   "*IF *VALUE KN3_Interface_Statistics.Bytes_Received *EQ 0 *AND *VALUE
 KN3_Interface_Statistics.Bytes_XMIT *EQ 0",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Interface_Xmit_Rcv_Bytes",
   "Kn3:KN320101731252461465",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_OSA2_Missed_Packets";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("00000000000000000000000020000000#W########F",
   "",
   "*NO",
   "",
   "en_US",
   "1130125110056000",
   "V100",
   "SYSADMIN",
   "",
   "*IF *VALUE OSA_10Gigabit_Ports_Errors.Missed_Packets *GT 0",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_OSA2_Missed_Packets",
   "Kn3:KN32008251058261003",
   "NNN",
   "COUNT=4;SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_OSA2_Not_Stored_Frames";

INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("00000000000000000000000020000000#W########F",
   "",
   "*NO",
   "",
   "en_US",
   "1130125110056000",
   "V100",
   "SYSADMIN",
   "",
   "*IF *VALUE OSA_10Gigabit_Ports_Errors.Not_Stored_Frames_Received *GT
 0",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_OSA2_Not_Stored_Frames",
   "Kn3:KN32008251058261004",
   "NNN",
   "COUNT=4;SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_OSA3_Missed_Packets";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("00000000000000000000000020000000#W########F",
   "",
   "*NO",
   "",
   "en_US",
   "1130125110056000",
   "V100",
   "SYSADMIN",
   "",
   "*IF *VALUE OSA_Express3_Ports_Errors.Missed_Packets *GT 0",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_OSA3_Missed_Packets",
   "Kn3:KN320082594761008",
   "NNN",
   "COUNT=4;SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_OSA3_Not_Stored_Frames";

INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("00000000000000000000000020000000#W########F",
   "",
   "*NO",
   "",
   "en_US",
   "1130125110056000",
   "V100",
   "SYSADMIN",
   "",
   "*IF *VALUE OSA_Express3_Ports_Errors.Not_Stored_Frames_RCV *GT 0",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_OSA3_Not_Stored_Frames",
   "Kn3:KN320082594761009",
   "NNN",
   "COUNT=4;SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_OSA_Chan_PCI_Busy_Pct_5M
in";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF  *VALUE OSA_Express_Channels.PCI_Utilization_Per_Five_Minutes *G
E 50",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_OSA_Chan_PCI_Busy_Pct_5Min",
   "Kn3:KN32036",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_OSA_Chan_Pro_Util_Pct_5M
in";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF  *VALUE OSA_Express_Channels.Processor_Utilization_Per_Five_Minu
tes *GE 50",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_OSA_Chan_Pro_Util_Pct_5Min",
   "Kn3:KN32037",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_OSA_Utilization";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE OSA_Express_Channels.PCI_Utilization_Per_Minute *GE 80 *A
ND  *VALUE OSA_Express_Channels.Processor_Utilization_Per_One_Hour *GE 9
5",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_OSA_Utilization",
   "Kn3:KN32038",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Output_Discard_Pct";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF  *VALUE TCPIP_Address_Space.Output_Discard_Percentage *GE 5",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Output_Discard_Pct",
   "Kn3:KN32039",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Paging_Rate";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF  *VALUE TCPIP_Address_Space.Paging_Rate *GE 5",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Paging_Rate",
   "Kn3:KN32040",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Pct_Auth_Pvt_Allocated_S
tg";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE TCPIP_Memory_Statistics.Pct_Private_Allocated *GE 80",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Pct_Auth_Pvt_Allocated_Stg",
   "Kn3:KN32041",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Pct_ECSA_Allocated_Stg";

INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE TCPIP_Memory_Statistics.Pct_ESCA_Allocated *GE 80",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Pct_ECSA_Allocated_Stg",
   "Kn3:KN32042",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Pct_IF_Err";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE Interfaces.Percent_Packets_in_Error *GE 3",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Pct_IF_Err",
   "Kn3:KN32043",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Pct_IF_In_Err";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE Interfaces.Percent_Inbound_Packets_in_Error *GE 2",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Pct_IF_In_Err",
   "Kn3:KN32044",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Pct_IF_Out_Err";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE Interfaces.Percent_Outbound_Packets_in_Error *GE 2",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Pct_IF_Out_Err",
   "Kn3:KN32045",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Pct_IF_Pkt_Disc";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE Interfaces.Percent_Packets_Discarded *GE 2",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Pct_IF_Pkt_Disc",
   "Kn3:KN32046",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Pct_IP_In_Disc";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE TCPIP_Stack_Layer.Input_Discard_Percentage *GE 3",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Pct_IP_In_Disc",
   "Kn3:KN32047",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Pct_TCP_OO_Segs";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE TCPIP_Stack_Layer.Pct_Out-of-Order-Segments_Last_Sample *
GE 15",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Pct_TCP_OO_Segs",
   "Kn3:KN32048",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Reassembly_Failure_Pct";

INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF  *VALUE TCPIP_Address_Space.Reassembly_Failure_Percentage *GE 5"
,
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Reassembly_Failure_Pct",
   "Kn3:KN32049",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Reassembly_Pct";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF  *VALUE TCPIP_Address_Space.Reassembly_Percentage *GE 5",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Reassembly_Pct",
   "Kn3:KN32050",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Retransmission_Pct";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF  *VALUE TCPIP_Address_Space.TCP_Retransmit_Percentage *GE 5",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Retransmission_Pct",
   "Kn3:KN32051",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Sample_NetViewAuto_Cmd";

INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000020000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130121080820000",
   "V100",
   "SYSADMIN",
   "",
   "*IF *VALUE TCPIP_Address_Space.CPU_Percentage *GE 0",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Sample_NetViewAuto_Cmd",
   "Kn3:KN32014_1",
   "NNN",
   "TFWD=N;OV=N;SEV=Harmless;TDST=0;~",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "F NetViewProcName,KN3SITEX N3T_Sample_NetViewAuto_Cmd CPUPercentage
 &{TCPIP_Address_Space.CPU_Percentage}"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Sample_NetViewAuto_Msg";

INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000020000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130121080820000",
   "V100",
   "SYSADMIN",
   "",
   "*IF *VALUE TCPIP_Address_Space.CPU_Percentage *GE 0",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Sample_NetViewAuto_Msg",
   "Kn3:KN32014_2",
   "NNN",
   "TFWD=N;OV=N;SEV=Harmless;TDST=0;~",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "SE 'N3T_Sample_NetViewAuto_Msg CPUPercentage  &{TCPIP_Address_Space.
CPU_Percentage}',CN=INTERNAL"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_TCP_Conn_Drop";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE TCPIP_Stack_Layer.TCP_Connections_Dropped_Last_Sample *GT
 0",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_TCP_Conn_Drop",
   "Kn3:KN32052",
   "NNN",
   "COUNT=3;SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_TCP_Flow_Controls";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000080000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130121080820000",
   "V4203",
   "SYSADMIN",
   "",
   "*IF *CHANGE KN3_TCP_Counter_Statistics.Total_Flow_Controls *GE 1",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_TCP_Flow_Controls",
   "Kn3:KN320101731252461466",
   "NNN",
   "COUNT=3;SEV=Informational",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_TCP_In_Errs";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE TCPIP_Stack_Layer.TCP_Received_Segment_Errors *GE 5",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_TCP_In_Errs",
   "Kn3:KN32053",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_TCP_Probes";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE TCPIP_Stack_Layer.TCP_Window_Probes_Sent_Last_Sample *GE
5",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_TCP_Probes",
   "Kn3:KN32054",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_TN3270_Avg_IP_Resp_Time"
;
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000008000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE TN3270_Server_Sess_Avail.Avg_IP_Response_Time *GT 1000",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_TN3270_Avg_IP_Resp_Time",
   "Kn3:KN3200673101281028",
   "NNY",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_TN3270_Avg_SNA_Resp_Time
";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000008000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE TN3270_Server_Sess_Avail.Avg_SNA_Response_Time *GT 500",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_TN3270_Avg_SNA_Resp_Time",
   "Kn3:KN3200673101281029",
   "NNY",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_TN3270_Avg_Tot_Resp_Time
";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000008000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE TN3270_Server_Sess_Avail.Avg_Total_Response_Time *GT 1500
",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_TN3270_Avg_Tot_Resp_Time",
   "Kn3:KN3200673101281030",
   "NNY",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_TN3270_Bckt5_Resp_Time_P
ct";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000008000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE TN3270_Server_Sess_Avail.Bucket_5_Response_Times_Pct *GE
10",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_TN3270_Bckt5_Resp_Time_Pct",
   "Kn3:KN3200673101281031",
   "NNY",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Telnet_Pool_Usage_Critic
al";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF  *VALUE TCPIP_Address_Space.Telnet_Pool_Percentage *GE 95",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Telnet_Pool_Usage_Critical",
   "Kn3:KN32055",
   "NNN",
   "SEV=Critical",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Telnet_Pool_Usage_Warnin
g";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF  *VALUE TCPIP_Address_Space.Telnet_Pool_Percentage *GE 80 *AND
*VALUE TCPIP_Address_Space.Telnet_Pool_Percentage *LT 95",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Telnet_Pool_Usage_Warning",
   "Kn3:KN32056",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Throughput_Rate";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF  *VALUE TCPIP_Address_Space.Byte_Rate *GE 2000000",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Throughput_Rate",
   "Kn3:KN32057",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Total_CSA_Pct";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF  *VALUE TCPIP_Address_Space.Total_CSA_Percentage *GE 5",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Total_CSA_Pct",
   "Kn3:KN32058",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_UDP_Discard_Pct";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000002000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF  *VALUE TCPIP_Address_Space.UDP_Discard_Percentage *GE 10",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_UDP_Discard_Pct",
   "Kn3:KN32059",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );

DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3V_BuffPool_Buf_Avail";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000004000000008000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE VTAM_Buffer_Pools.Expansion_Threshold_Flag *EQ Yes",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3V_BuffPool_Buf_Avail",
   "Kn3:KN3_2005_340_5_5_25_1000",
   "NNY",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3V_BuffPool_Buf_Expan_Lim_P
ct";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000004000000008000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE VTAM_Buffer_Pools.IO_Expansion_Limit_Percent *GT 90",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3V_BuffPool_Buf_Expan_Lim_Pct",
   "Kn3:KN3_2005_356_9_52_32_1000",
   "NNY",
   "SEV=Critical",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3V_BuffPool_Queue_Req";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000004000000008000000000",
   "",
   "*NO",
   "",
   "en_US",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE VTAM_Buffer_Pools.Queued_Requests *GT 0",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3V_BuffPool_Queue_Req",
   "Kn3:KN3_2005_356_9_52_32_1001",
   "NNY",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3V_CPU_Pct_Critical";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000004000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE VTAM_Address_Space.CPU_Percentage *GE 10",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3V_CPU_Pct_Critical",
   "Kn3:KN32060",
   "NNN",
   "SEV=Critical",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3V_CPU_Pct_Warning";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000004000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110055000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE VTAM_Address_Space.CPU_Percentage *GE 5 *AND  *VALUE VTAM
_Address_Space.CPU_Percentage *LT 10",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3V_CPU_Pct_Warning",
   "Kn3:KN32061",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3V_CSA_Pct_Below_16MB";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000004000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE VTAM_Address_Space.CSA_Percent_Below_16MB *GE 5",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3V_CSA_Pct_Below_16MB",
   "Kn3:KN32062",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3V_EE_Pct_Packets_Rexmit";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000004000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE EE_Connections.Percent_Packets_Retransmitted *GE 5",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3V_EE_Pct_Packets_Rexmit",
   "Kn3:KN32063",
   "NNN",
   "COUNT=2;SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3V_HPR_Conn_OOS_Buffers";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000004000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE HPR_RTP_Connections.Out_of_Sequence_Buffers *GE 100",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3V_HPR_Conn_OOS_Buffers",
   "Kn3:KN32064",
   "NNN",
   "COUNT=2;SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3V_HPR_Conn_Path_Switch";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000004000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE HPR_RTP_Connections.Number_Path_Switches *GT 0 *AND *VALU
E HPR_RTP_Connections.Path_Switch_Trigger *LE No_NCB",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3V_HPR_Conn_Path_Switch",
   "Kn3:KN32065",
   "NNN",
   "COUNT=3;SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3V_HPR_Throughput";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000004000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE HPR_RTP_Connections.Packets_Queued *GT 0 *AND  *VALUE HPR
_RTP_Connections.Compare_Throughput_Rate *EQ 1",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3V_HPR_Throughput",
   "Kn3:KN32066",
   "NNN",
   "COUNT=3;SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3V_Paging_Rate";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000004000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE VTAM_Address_Space.Paging_Rate *GE 5",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3V_Paging_Rate",
   "Kn3:KN32067",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3V_Pct_ECSA_Allocated_Stg";

INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000004000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE CSM_Storage.Pct_ESCA_Allocated *GE 80",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3V_Pct_ECSA_Allocated_Stg",
   "Kn3:KN32068",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3V_Total_CSA_Pct";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("0000000000000000000000004000000000000000000",
   "",
   "*NO",
   "",
   "",
   "1130125110056000",
   "V420",
   "SYSADMIN",
   "",
   "*IF *VALUE VTAM_Address_Space.Total_CSA_Percentage *GE 5",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3V_Total_CSA_Pct",
   "Kn3:KN32069",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );

/* ------------------------------------------------------------------ */
/* Start of @10 - Situations for VTAM applications                    */
/* ------------------------------------------------------------------ */
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3V_Appl_Not_Active";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("%IBM.STATIC148          000000000H#########",
   "",
   "*NO",
   "",
   "",
   "1190307095531000",
   "V5503",
   "SYSADMIN",
   "",
   "*IF  *VALUE KN3_VTAM_Applications.Current_State *NE Active",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3V_Appl_Not_Active",
   "Kn3:KN3VAP_V5503_SIT01",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3V_Appl_Not_Ready";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("%IBM.STATIC148          000000000H#########",
   "",
   "*NO",
   "",
   "",
   "1190307095531000",
   "V5503",
   "SYSADMIN",
   "",
   "*IF  *VALUE KN3_VTAM_Applications.Application_Name *EQ applname *AND
 *VALUE KN3_VTAM_Applications.Status_CINIT *EQ No",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3V_Appl_Not_Ready",
   "Kn3:KN3VAP_V5503_SIT02",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3V_Appl_Active_Sess";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("%IBM.STATIC148          000000000H#########",
   "",
   "*NO",
   "",
   "",
   "1190307095531000",
   "V5503",
   "SYSADMIN",
   "",
   "*IF  *VALUE KN3_VTAM_Applications.Sessions_Active *GE 100",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3V_Appl_Active_Sess",
   "Kn3:KN3VAP_V5503_SIT03",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3V_Appl_Pending_Sess";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("%IBM.STATIC148          000000000H#########",
   "",
   "*NO",
   "",
   "",
   "1190307095531000",
   "V5503",
   "SYSADMIN",
   "",
   "*IF  *VALUE KN3_VTAM_Applications.Sessions_Pending_Active *GE 10",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3V_Appl_Pending_Sess",
   "Kn3:KN3VAP_V5503_SIT04",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3V_Appl_Sessions_Waiting";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("%IBM.STATIC148          000000000H#########",
   "",
   "*NO",
   "",
   "",
   "1190307095531000",
   "V5503",
   "SYSADMIN",
   "",
   "*IF  *VALUE KN3_VTAM_Applications.Total_Sessions_Waiting *GT 0",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3V_Appl_Sessions_Waiting",
   "Kn3:KN3VAP_V5503_SIT05",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3V_Sessions_Send_Count";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("%IBM.STATIC148          000000000H#########",
   "",
   "*NO",
   "",
   "",
   "1190307095531000",
   "V5503",
   "SYSADMIN",
   "",
   "*IF  *VALUE KN3_VTAM_Sessions.Sends *GE 1000",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3V_Sessions_Send_Count",
   "Kn3:KN3VSS_V5503_SIT01",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3V_Sessions_Receive_Count";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("%IBM.STATIC148          000000000H#########",
   "",
   "*NO",
   "",
   "",
   "1190307095531000",
   "V5503",
   "SYSADMIN",
   "",
   "*IF  *VALUE KN3_VTAM_Sessions.Receives *GE 1000",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3V_Sessions_Receive_Count",
   "Kn3:KN3VSS_V5503_SIT02",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
/* ------------------------------------------------------------------ */
/* End of @10 - Situations for VTAM applications                      */
/* ------------------------------------------------------------------ */
/* ------------------------------------------------------------------ */
/* Start of @11 - Situations for zERT                                 */
/* ------------------------------------------------------------------ */
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Outdated_SSH_Protocol";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("%IBM.STATIC149          000000000I#########",
   "",
   "*NO",
   "",
   "",
   "1190917074246000",
   "V5504",
   "SYSADMIN",
   "",
   "*IF *VALUE KN3_ZERT_SSH_Summary.SSH_Version *LT Protocol_version_2",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Outdated_SSH_Protocol",
   "Kn3:KN3ZAH_V5504_SIT01",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );

DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_Outdated_TLS_Protocol";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("%IBM.STATIC149          000000000I#########",
   "",
   "*NO",
   "",
   "",
   "1190917074246000",
   "V5504",
   "SYSADMIN",
   "",
   "*IF *VALUE KN3_ZERT_TLS_Summary.TLS_Version *LT TLSv1.2",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_Outdated_TLS_Protocol",
   "Kn3:KN3ZAT_V5504_SIT01",
   "NNN",
   "SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
/* ------------------------------------------------------------------ */
/* End of @11 - Situations for zERT                                   */
/* ------------------------------------------------------------------ */
/* ------------------------------------------------------------------ */
/* Start of @12 - Situations for OSA7S & OSA5S                        */
/* ------------------------------------------------------------------ */
DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_OSA5S_Jabber_Frames";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("%IBM.STATIC149          000000000E#########",
   "",
   "*NO",
   "",
   "",
   "1200714070700000",
   "V5505",
   "SYSADMIN",
   "",
   "*IF *VALUE KN3_OSA_Express5S_Ports_Errors.JBRRCV *GT 0",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_OSA5S_Jabber_Frames",
   "Kn3:KN35SE_V5505_SIT01",
   "NNN",
   "COUNT=4;SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );

DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_OSA5S_No_Free_LAN_Desc";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("%IBM.STATIC149          000000000E#########",
   "",
   "*NO",
   "",
   "",
   "1200714070700000",
   "V5505",
   "SYSADMIN",
   "",
   "*IF *VALUE KN3_OSA_Express5S_Ports_Errors.NOLANDESC *GT 0",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_OSA5S_No_Free_LAN_Desc",
   "Kn3:KN35SE_V5505_SIT02",
   "NNN",
   "COUNT=4;SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );

DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_OSA5S_No_Free_NIC_Buff";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("%IBM.STATIC149          000000000E#########",
   "",
   "*NO",
   "",
   "",
   "1200714070700000",
   "V5505",
   "SYSADMIN",
   "",
   "*IF *VALUE KN3_OSA_Express5S_Ports_Errors.NONICBUF *GT 0",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_OSA5S_No_Free_NIC_Buff",
   "Kn3:KN35SE_V5505_SIT03",
   "NNN",
   "COUNT=4;SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );

DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_OSA5S_No_Free_NIC_Desc";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("%IBM.STATIC149          000000000E#########",
   "",
   "*NO",
   "",
   "",
   "1200714070700000",
   "V5505",
   "SYSADMIN",
   "",
   "*IF *VALUE KN3_OSA_Express5S_Ports_Errors.NONICDESC *GT 0",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_OSA5S_No_Free_NIC_Desc",
   "Kn3:KN35SE_V5505_SIT04",
   "NNN",
   "COUNT=4;SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );

DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_OSA7S_Fragments_Received
";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("%IBM.STATIC149          000000000J#########",
   "",
   "*NO",
   "",
   "",
   "1200714070700000",
   "V5505",
   "SYSADMIN",
   "",
   "*IF *VALUE KN3_OSA_Express7S.FR *GT 0",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_OSA7S_Fragments_Received",
   "Kn3:KN3TO7_V5505_SIT01",
   "NNN",
   "COUNT=4;SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );

DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_OSA7S_Illegal_Bytes";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("%IBM.STATIC149          000000000J#########",
   "",
   "*NO",
   "",
   "",
   "1200714070700000",
   "V5505",
   "SYSADMIN",
   "",
   "*IF *VALUE KN3_OSA_Express7S.IBE *GT 0",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_OSA7S_Illegal_Bytes",
   "Kn3:KN3TO7_V5505_SIT02",
   "NNN",
   "COUNT=4;SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );

DELETE FROM O4SRV.TSITDESC WHERE SITNAME = "N3T_OSA7S_Jabber_Frames";
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES,
   ALERTLIST,
   AUTOSTART,
   HUB,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   OBJECTLOCK,
   PDT,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   SENDMSGQ,
   SITNAME,
   TEXT,
   AUTOSOPT,
   SITINFO,
   ADVISE,
   CMD  )
VALUES
  ("%IBM.STATIC149          000000000J#########",
   "",
   "*NO",
   "",
   "",
   "1200714070700000",
   "V5505",
   "SYSADMIN",
   "",
   "*IF *VALUE KN3_OSA_Express7S.JBRRCV *GT 0",
   "E",
   "0",
   "001500",
   "*NONE",
   "N3T_OSA7S_Jabber_Frames",
   "Kn3:KN3TO7_V5505_SIT03",
   "NNN",
   "COUNT=4;SEV=Warning",
   'ADVICE("kn3:"+$ISITSTSH.SITNAME$);',
   "*NONE"
  );
/* ------------------------------------------------------------------ */
/* End of @12 - Situations for OSA7S & OSA5S                          */
/* ------------------------------------------------------------------ */

/* ------------------------------------------------------------------ */
/* End of data                                                        */
/* ------------------------------------------------------------------ */
